==> core_models-0.1.0.gem: app/controllers/core_models/people_and_companies/bank_payment_cards_controller.rb <==
require_dependency "core_models/core_models_controller"

module CoreModels
  class PeopleAndCompanies::BankPaymentCardsController < CoreModelsController
    # GET /people_and_companies/bank_payment_cards
    # GET /people_and_companies/bank_payment_cards.json
    def index
      @people_and_companies_bank_payment_cards = PeopleAndCompanies::BankPaymentCard.all

      respond_to do |format|
        format.html # index.html.erb
        format.json { render :json => @people_and_companies_bank_payment_cards }
      end
    end

    # GET /people_and_companies/bank_payment_cards/1
    # GET /people_and_companies/bank_payment_cards/1.json
    def show
      @people_and_companies_bank_payment_card = PeopleAndCompanies::BankPaymentCard.find(params[:id])

      respond_to do |format|
        format.html # show.html.erb
        format.json { render :json => @people_and_companies_bank_payment_card }
      end
    end

    # GET /people_and_companies/bank_payment_cards/new
    # GET /people_and_companies/bank_payment_cards/new.json
    def new
      @people_and_companies_bank_payment_card = PeopleAndCompanies::BankPaymentCard.new

      respond_to do |format|
        format.html # new.html.erb
        format.json { render :json => @people_and_companies_bank_payment_card }
      end
    end

    # GET /people_and_companies/bank_payment_cards/1/edit
    def edit
      @people_and_companies_bank_payment_card = PeopleAndCompanies::BankPaymentCard.find(params[:id])
    end

    # POST /people_and_companies/bank_payment_cards
    # POST /people_and_companies/bank_payment_cards.json
    def create
      @people_and_companies_bank_payment_card = PeopleAndCompanies::BankPaymentCard.new(params[:people_and_companies_bank_payment_card])

      respond_to do |format|
        if @people_and_companies_bank_payment_card.save
          format.html { redirect_to @people_and_companies_bank_payment_card, :notice => 'Bank payment card was successfully created.' }
          format.json { render :json => @people_and_companies_bank_payment_card, :status => :created, :location => @people_and_companies_bank_payment_card }
        else
          format.html { render :action => "new" }
          format.json { render :json => @people_and_companies_bank_payment_card.errors, :status => :unprocessable_entity }
        end
      end
    end

    # PUT /people_and_companies/bank_payment_cards/1
    # PUT /people_and_companies/bank_payment_cards/1.json
    def update
      @people_and_companies_bank_payment_card = PeopleAndCompanies::BankPaymentCard.find(params[:id])

      respond_to do |format|
        if @people_and_companies_bank_payment_card.update_attributes(params[:people_and_companies_bank_payment_card])
          format.html { redirect_to @people_and_companies_bank_payment_card, :notice => 'Bank payment card was successfully updated.' }
          format.json { head :no_content }
        else
          format.html { render :action => "edit" }
          format.json { render :json => @people_and_companies_bank_payment_card.errors, :status => :unprocessable_entity }
        end
      end
    end

    # DELETE /people_and_companies/bank_payment_cards/1
    # DELETE /people_and_companies/bank_payment_cards/1.json
    def destroy
      @people_and_companies_bank_payment_card = PeopleAndCompanies::BankPaymentCard.find(params[:id])
      @people_and_companies_bank_payment_card.destroy

      respond_to do |format|
        format.html { redirect_to people_and_companies_bank_payment_cards_url }
        format.json { head :no_content }
      end
    end
  end
end

==> core_models-0.2.9.gem: app/controllers/core_models/people_and_companies/bank_payment_cards_controller.rb <==
require_dependency "core_models/core_models_controller"

module CoreModels
  class PeopleAndCompanies::BankPaymentCardsController < CoreModelsController
    # GET /people_and_companies/bank_payment_cards
    # GET /people_and_companies/bank_payment_cards.json
    def index
      @people_and_companies_bank_payment_cards = PeopleAndCompanies::BankPaymentCard.all

      respond_to do |format|
        format.html # index.html.erb
        format.json { render :json => @people_and_companies_bank_payment_cards }
      end
    end

    # GET /people_and_companies/bank_payment_cards/1
    # GET /people_and_companies/bank_payment_cards/1.json
    def show
      @people_and_companies_bank_payment_card = PeopleAndCompanies::BankPaymentCard.find(params[:id])

      respond_to do |format|
        format.html # show.html.erb
        format.json { render :json => @people_and_companies_bank_payment_card }
      end
    end

    # GET /people_and_companies/bank_payment_cards/new
    # GET /people_and_companies/bank_payment_cards/new.json
    def new
      @people_and_companies_bank_payment_card = PeopleAndCompanies::BankPaymentCard.new

      respond_to do |format|
        format.html # new.html.erb
        format.json { render :json => @people_and_companies_bank_payment_card }
      end
    end

    # GET /people_and_companies/bank_payment_cards/1/edit
    def edit
      @people_and_companies_bank_payment_card = PeopleAndCompanies::BankPaymentCard.find(params[:id])
    end

    # POST /people_and_companies/bank_payment_cards
    # POST /people_and_companies/bank_payment_cards.json
    def create
      @people_and_companies_bank_payment_card = PeopleAndCompanies::BankPaymentCard.new(params[:people_and_companies_bank_payment_card])

      respond_to do |format|
        if @people_and_companies_bank_payment_card.save
          format.html { redirect_to @people_and_companies_bank_payment_card, :notice => 'Bank payment card was successfully created.' }
          format.json { render :json => @people_and_companies_bank_payment_card, :status => :created, :location => @people_and_companies_bank_payment_card }
        else
          format.html { render :action => "new" }
          format.json { render :json => @people_and_companies_bank_payment_card.errors, :status => :unprocessable_entity }
        end
      end
    end

    # PUT /people_and_companies/bank_payment_cards/1
    # PUT /people_and_companies/bank_payment_cards/1.json
    def update
      @people_and_companies_bank_payment_card = PeopleAndCompanies::BankPaymentCard.find(params[:id])

      respond_to do |format|
        if @people_and_companies_bank_payment_card.update(params[:people_and_companies_bank_payment_card])
          format.html { redirect_to @people_and_companies_bank_payment_card, :notice => 'Bank payment card was successfully updated.' }
          format.json { head :no_content }
        else
          format.html { render :action => "edit" }
          format.json { render :json => @people_and_companies_bank_payment_card.errors, :status => :unprocessable_entity }
        end
      end
    end

    # DELETE /people_and_companies/bank_payment_cards/1
    # DELETE /people_and_companies/bank_payment_cards/1.json
    def destroy
      @people_and_companies_bank_payment_card = PeopleAndCompanies::BankPaymentCard.find(params[:id])
      @people_and_companies_bank_payment_card.destroy

      respond_to do |format|
        format.html { redirect_to people_and_companies_bank_payment_cards_url }
        format.json { head :no_content }
      end
    end
  end
end
